<template>
  <el-upload
    name="files"
    :action="CommonApi.uploadUrl"
    :headers="header"
    :file-list="fileList"
    :on-success="attachmentUploadSuccess"
    :before-upload="attachmentBeforeUpload"
    list-type="picture-card"
  >
    <!-- accept=".doc, .png, .jpeg, .pdf, .webp, .jpg, .docx, .xls, .xlsx" -->
    <i slot="default" class="el-icon-circle-plus" />
    <div slot="file" slot-scope="{file}">
      <div class="el-upload-list__item-thumbnail" style="font-size:12px">
        <img
          :src="file.extensionName==='pdf'?pdfImg:(file.extensionName==='doc'||file.extensionName==='docx')?wordImg:(file.extensionName==='xls'||file.extensionName==='xlsx')?xlsImg:(file.extensionName==='png'||file.extensionName==='jpg'||file.extensionName==='jpeg')?imgInfo:defaultImg"
          alt
        />
        <div class="file-names">{{file.name}}</div>
      </div>
      <span class="el-upload-list__item-actions">
        <span class="el-upload-list__item-delete" @click="downFile(file)">
          <i class="el-icon-download"></i>
        </span>
        <span class="el-upload-list__item-delete" @click="attachmentHandleFileDelete(file)">
          <i class="el-icon-delete"></i>
        </span>
      </span>
    </div>
  </el-upload>
</template>

<script>
import CommonApi from '@/views/Manage/CommonApi.js'
import {mapState} from 'vuex'
export default {
    name: 'fileUpload', // 文件上传
    data() {
        return {
            CommonApi,
            pdfImg: require('@/assets/img/pdf.png'),
            wordImg: require('@/assets/img/word.png'),
            imgInfo: require('@/assets/img/img.png'),
            xlsImg: require('@/assets/img/xls.png'),
            defaultImg: require('@/assets/img/default.png')
        }
    },
    props: {
        fileList: {
            type: Array,
            default: []
        }
    },
    computed: mapState({
        header: state => {
            return {
                Authorization: `Bearer ${state.login.currentUser.token}`
            }
        }
    }),
    created() {},
    methods: {
        // 删除文件
        attachmentHandleFileDelete(file) {
            this.$emit('attachmentHandleFileDelete', file)
        },
        // 下载文件
        downFile(file) {
            // this.$emit('downFile', file)
            CommonApi.downloadFile(file.id)
        },
        // 上传成功前钩子函数
        attachmentBeforeUpload(file) {
            // this.$emit('attachmentBeforeUpload', file)
            const isLt1M = file.size / 1024 / 1024 < 100
            if (!isLt1M) {
                this.$message.error('上传文件不能超过 100MB!')
            }
            return isLt1M
        },
        // 上传成功后函数
        attachmentUploadSuccess(res, file, fileList) {
            this.$emit('attachmentUploadSuccess', res, file, fileList)
        }
    }
}
</script>

<style scoped lang="scss">
::v-deep .el-upload--picture-card {
    height: 100px;
    width: 100px;
    line-height: 100px;
}
::v-deep .el-upload-list--picture-card {
    .el-upload-list__item {
        height: 100px !important;
        width: 100px !important;
    }
}

.el-upload-list__item-thumbnail {
    padding-top: 20px;
    display: flex;
    align-items: center;
    justify-content: center;
    flex-direction: column;
    height: 100%;
    img {
        width: 40px;
        height: 40px;
        margin-bottom: 5px;
    }
    .file-names {
        width: 90%;
        margin: 0 auto;
        white-space: nowrap;
        text-overflow: ellipsis;
        overflow: hidden;
    }
}
::v-deep .el-upload-list__item {
    transition: none !important;
    -webkit-transition: none !important;
}
::v-deep .el-upload-list__item-name {
    transition: none !important;
    -webkit-transition: none !important;
}
</style>
